@@ -11,7 +11,7 @@
 //! `smolscale` also includes `Nursery`, a helper for [structured concurrency](https://vorpus.org/blog/notes-on-structured-concurrency-or-go-statement-considered-harmful/) on the `smolscale` global executor.
 
 use futures_lite::prelude::*;
-use once_cell::sync::OnceCell;
+use once_cell::sync::{Lazy, OnceCell};
 use std::{
     pin::Pin,
     sync::atomic::AtomicUsize,
@@ -19,18 +19,21 @@ use std::{
     task::{Context, Poll},
     time::{Duration, Instant},
 };
+mod executor;
 mod nursery;
+mod sp2c;
+pub use executor::*;
 pub use nursery::*;
 
 //const CHANGE_THRESH: u32 = 10;
-const MONITOR_MS: u64 = 200;
+const MONITOR_MS: u64 = 50;
 
 const MAX_THREADS: usize = 500;
 
 // thread_local! {
 //     static LEXEC: Rc<async_executor::LocalExecutor<'static>> = Rc::new(async_executor::LocalExecutor::new())
 // }
-static EXEC: async_executor::Executor<'static> = async_executor::Executor::new();
+static EXEC: Lazy<Executor> = Lazy::new(Executor::new);
 
 static FUTURES_BEING_POLLED: AtomicUsize = AtomicUsize::new(0);
 static POLL_COUNT: AtomicUsize = AtomicUsize::new(0);
@@ -75,12 +78,14 @@ fn monitor_loop() {
                     });
                     // let run_local = local_exec.run(futures_lite::future::pending::<()>());
                     if exitable {
-                        EXEC.run(async {
-                            async_io::Timer::after(Duration::from_secs(5)).await;
-                        })
-                        .await;
+                        EXEC.worker()
+                            .run()
+                            .or(async {
+                                async_io::Timer::after(Duration::from_secs(5)).await;
+                            })
+                            .await;
                     } else {
-                        EXEC.run(futures_lite::future::pending::<()>()).await;
+                        EXEC.worker().run().await;
                     };
                 };
                 if process_io {
@@ -101,6 +106,7 @@ fn monitor_loop() {
     }
 
     loop {
+        EXEC.rebalance();
         if SINGLE_THREAD.load(Ordering::Relaxed) {
             return;
         }
